import * as Core from "../../../core.js";
import { APIResource } from "../../../resource.js";
import * as DelegationsAPI from "./delegations.js";
import { SinglePage } from "../../../pagination.js";
export declare class Delegations extends APIResource {
    /**
     * Create a new account delegation for a given IP prefix.
     */
    create(prefixId: string, params: DelegationCreateParams, options?: Core.RequestOptions): Core.APIPromise<Delegations>;
    /**
     * List all delegations for a given account IP prefix.
     */
    list(prefixId: string, params: DelegationListParams, options?: Core.RequestOptions): Core.PagePromise<DelegationsSinglePage, Delegations>;
    /**
     * Delete an account delegation for a given IP prefix.
     */
    delete(prefixId: string, delegationId: string, params: DelegationDeleteParams, options?: Core.RequestOptions): Core.APIPromise<DelegationDeleteResponse>;
}
export declare class DelegationsSinglePage extends SinglePage<Delegations> {
}
export interface Delegations {
    /**
     * Delegation identifier tag.
     */
    id?: string;
    /**
     * IP Prefix in Classless Inter-Domain Routing format.
     */
    cidr?: string;
    created_at?: string;
    /**
     * Account identifier for the account to which prefix is being delegated.
     */
    delegated_account_id?: string;
    modified_at?: string;
    /**
     * Identifier
     */
    parent_prefix_id?: string;
}
export interface DelegationDeleteResponse {
    /**
     * Delegation identifier tag.
     */
    id?: string;
}
export interface DelegationCreateParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param: IP Prefix in Classless Inter-Domain Routing format.
     */
    cidr: string;
    /**
     * Body param: Account identifier for the account to which prefix is being
     * delegated.
     */
    delegated_account_id: string;
}
export interface DelegationListParams {
    /**
     * Identifier
     */
    account_id: string;
}
export interface DelegationDeleteParams {
    /**
     * Identifier
     */
    account_id: string;
}
export declare namespace Delegations {
    export import Delegations = DelegationsAPI.Delegations;
    export import DelegationDeleteResponse = DelegationsAPI.DelegationDeleteResponse;
    export import DelegationsSinglePage = DelegationsAPI.DelegationsSinglePage;
    export import DelegationCreateParams = DelegationsAPI.DelegationCreateParams;
    export import DelegationListParams = DelegationsAPI.DelegationListParams;
    export import DelegationDeleteParams = DelegationsAPI.DelegationDeleteParams;
}
//# sourceMappingURL=delegations.d.ts.map