import * as Core from "../../core.js";
import { APIResource } from "../../resource.js";
import * as ConfigurationsAPI from "./configurations.js";
export declare class Configurations extends APIResource {
    /**
     * Set configuration properties
     */
    update(params: ConfigurationUpdateParams, options?: Core.RequestOptions): Core.APIPromise<ConfigurationUpdateResponse>;
    /**
     * Retrieve information about specific configuration properties
     */
    get(params: ConfigurationGetParams, options?: Core.RequestOptions): Core.APIPromise<Configuration>;
}
export interface Configuration {
    auth_id_characteristics?: Array<Configuration.APIShieldAuthIDCharacteristic | Configuration.APIShieldAuthIDCharacteristicJwtClaim>;
}
export declare namespace Configuration {
    /**
     * Auth ID Characteristic
     */
    interface APIShieldAuthIDCharacteristic {
        /**
         * The name of the characteristic field, i.e., the header or cookie name.
         */
        name: string;
        /**
         * The type of characteristic.
         */
        type: 'header' | 'cookie';
    }
    /**
     * Auth ID Characteristic extracted from JWT Token Claims
     */
    interface APIShieldAuthIDCharacteristicJwtClaim {
        /**
         * Claim location expressed as `$(token_config_id):$(json_path)`, where
         * `token_config_id` is the ID of the token configuration used in validating the
         * JWT, and `json_path` is a RFC 9535 JSONPath
         * (https://goessner.net/articles/JsonPath/,
         * https://www.rfc-editor.org/rfc/rfc9535.html). The JSONPath expression may be in
         * dot or bracket notation, may only specify literal keys or array indexes, and
         * must return a singleton value, which will be interpreted as a string.
         */
        name: string;
        /**
         * The type of characteristic.
         */
        type: 'jwt';
    }
}
export type ConfigurationUpdateResponse = unknown | string | null;
export interface ConfigurationUpdateParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param:
     */
    auth_id_characteristics?: Array<ConfigurationUpdateParams.APIShieldAuthIDCharacteristic | ConfigurationUpdateParams.APIShieldAuthIDCharacteristicJwtClaim>;
}
export declare namespace ConfigurationUpdateParams {
    /**
     * Auth ID Characteristic
     */
    interface APIShieldAuthIDCharacteristic {
        /**
         * The name of the characteristic field, i.e., the header or cookie name.
         */
        name: string;
        /**
         * The type of characteristic.
         */
        type: 'header' | 'cookie';
    }
    /**
     * Auth ID Characteristic extracted from JWT Token Claims
     */
    interface APIShieldAuthIDCharacteristicJwtClaim {
        /**
         * Claim location expressed as `$(token_config_id):$(json_path)`, where
         * `token_config_id` is the ID of the token configuration used in validating the
         * JWT, and `json_path` is a RFC 9535 JSONPath
         * (https://goessner.net/articles/JsonPath/,
         * https://www.rfc-editor.org/rfc/rfc9535.html). The JSONPath expression may be in
         * dot or bracket notation, may only specify literal keys or array indexes, and
         * must return a singleton value, which will be interpreted as a string.
         */
        name: string;
        /**
         * The type of characteristic.
         */
        type: 'jwt';
    }
}
export interface ConfigurationGetParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Query param: Requests information about certain properties.
     */
    properties?: Array<'auth_id_characteristics'>;
}
export declare namespace Configurations {
    export import Configuration = ConfigurationsAPI.Configuration;
    export import ConfigurationUpdateResponse = ConfigurationsAPI.ConfigurationUpdateResponse;
    export import ConfigurationUpdateParams = ConfigurationsAPI.ConfigurationUpdateParams;
    export import ConfigurationGetParams = ConfigurationsAPI.ConfigurationGetParams;
}
//# sourceMappingURL=configurations.d.ts.map