import * as Core from "../../core.js";
import { APIResource } from "../../resource.js";
import * as DNSAPI from "./dns.js";
export declare class DNS extends APIResource {
    /**
     * Show the DNS records needed to configure your Email Routing zone.
     */
    get(zoneIdentifier: string, options?: Core.RequestOptions): Core.APIPromise<DNSGetResponse | null>;
}
/**
 * List of records needed to enable an Email Routing zone.
 */
export interface DNSRecord {
    /**
     * DNS record content.
     */
    content?: string;
    /**
     * DNS record name (or @ for the zone apex).
     */
    name?: string;
    /**
     * Required for MX, SRV and URI records. Unused by other record types. Records with
     * lower priorities are preferred.
     */
    priority?: number;
    /**
     * Time to live, in seconds, of the DNS record. Must be between 60 and 86400, or 1
     * for 'automatic'.
     */
    ttl?: number | 1;
    /**
     * DNS record type.
     */
    type?: 'A' | 'AAAA' | 'CNAME' | 'HTTPS' | 'TXT' | 'SRV' | 'LOC' | 'MX' | 'NS' | 'CERT' | 'DNSKEY' | 'DS' | 'NAPTR' | 'SMIMEA' | 'SSHFP' | 'SVCB' | 'TLSA' | 'URI';
}
export type DNSGetResponse = Array<DNSRecord>;
export declare namespace DNS {
    export import DNSRecord = DNSAPI.DNSRecord;
    export import DNSGetResponse = DNSAPI.DNSGetResponse;
}
//# sourceMappingURL=dns.d.ts.map