import * as Core from "../../../core.js";
import { APIResource } from "../../../resource.js";
import * as ByTagAPI from "./by-tag.js";
import * as RulesAPI from "../rules.js";
import * as RulesetsAPI from "../rulesets.js";
export declare class ByTag extends APIResource {
    /**
     * Fetches the rules of a managed account ruleset version for a given tag.
     */
    get(rulesetId: string, rulesetVersion: string, ruleTag: string, params: ByTagGetParams, options?: Core.RequestOptions): Core.APIPromise<ByTagGetResponse>;
}
/**
 * A ruleset object.
 */
export interface ByTagGetResponse {
    /**
     * The unique ID of the ruleset.
     */
    id: string;
    /**
     * The kind of the ruleset.
     */
    kind: RulesetsAPI.Kind;
    /**
     * The timestamp of when the ruleset was last modified.
     */
    last_updated: string;
    /**
     * The human-readable name of the ruleset.
     */
    name: string;
    /**
     * The phase of the ruleset.
     */
    phase: RulesetsAPI.Phase;
    /**
     * The list of rules in the ruleset.
     */
    rules: Array<RulesAPI.BlockRule | RulesAPI.ChallengeRule | RulesAPI.CompressResponseRule | RulesAPI.ExecuteRule | RulesAPI.JSChallengeRule | RulesAPI.LogRule | RulesAPI.ManagedChallengeRule | RulesAPI.RedirectRule | RulesAPI.RewriteRule | RulesAPI.RouteRule | RulesAPI.ScoreRule | RulesAPI.ServeErrorRule | RulesAPI.SetConfigRule | RulesAPI.SkipRule | RulesAPI.SetCacheSettingsRule | ByTagGetResponse.RulesetsLogCustomFieldRule | ByTagGetResponse.RulesetsDDoSDynamicRule | ByTagGetResponse.RulesetsForceConnectionCloseRule>;
    /**
     * The version of the ruleset.
     */
    version: string;
    /**
     * An informative description of the ruleset.
     */
    description?: string;
}
export declare namespace ByTagGetResponse {
    interface RulesetsLogCustomFieldRule {
        /**
         * The timestamp of when the rule was last modified.
         */
        last_updated: string;
        /**
         * The version of the rule.
         */
        version: string;
        /**
         * The unique ID of the rule.
         */
        id?: string;
        /**
         * The action to perform when the rule matches.
         */
        action?: 'log_custom_field';
        /**
         * The parameters configuring the rule's action.
         */
        action_parameters?: RulesetsLogCustomFieldRule.ActionParameters;
        /**
         * The categories of the rule.
         */
        categories?: Array<string>;
        /**
         * An informative description of the rule.
         */
        description?: string;
        /**
         * Whether the rule should be executed.
         */
        enabled?: boolean;
        /**
         * The expression defining which traffic will match the rule.
         */
        expression?: string;
        /**
         * An object configuring the rule's logging behavior.
         */
        logging?: RulesAPI.Logging;
        /**
         * The reference of the rule (the rule ID by default).
         */
        ref?: string;
    }
    namespace RulesetsLogCustomFieldRule {
        /**
         * The parameters configuring the rule's action.
         */
        interface ActionParameters {
            /**
             * The cookie fields to log.
             */
            cookie_fields?: Array<ActionParameters.CookieField>;
            /**
             * The request fields to log.
             */
            request_fields?: Array<ActionParameters.RequestField>;
            /**
             * The response fields to log.
             */
            response_fields?: Array<ActionParameters.ResponseField>;
        }
        namespace ActionParameters {
            /**
             * The cookie field to log.
             */
            interface CookieField {
                /**
                 * The name of the field.
                 */
                name: string;
            }
            /**
             * The request field to log.
             */
            interface RequestField {
                /**
                 * The name of the field.
                 */
                name: string;
            }
            /**
             * The response field to log.
             */
            interface ResponseField {
                /**
                 * The name of the field.
                 */
                name: string;
            }
        }
    }
    interface RulesetsDDoSDynamicRule {
        /**
         * The timestamp of when the rule was last modified.
         */
        last_updated: string;
        /**
         * The version of the rule.
         */
        version: string;
        /**
         * The unique ID of the rule.
         */
        id?: string;
        /**
         * The action to perform when the rule matches.
         */
        action?: 'ddos_dynamic';
        /**
         * The parameters configuring the rule's action.
         */
        action_parameters?: unknown;
        /**
         * The categories of the rule.
         */
        categories?: Array<string>;
        /**
         * An informative description of the rule.
         */
        description?: string;
        /**
         * Whether the rule should be executed.
         */
        enabled?: boolean;
        /**
         * The expression defining which traffic will match the rule.
         */
        expression?: string;
        /**
         * An object configuring the rule's logging behavior.
         */
        logging?: RulesAPI.Logging;
        /**
         * The reference of the rule (the rule ID by default).
         */
        ref?: string;
    }
    interface RulesetsForceConnectionCloseRule {
        /**
         * The timestamp of when the rule was last modified.
         */
        last_updated: string;
        /**
         * The version of the rule.
         */
        version: string;
        /**
         * The unique ID of the rule.
         */
        id?: string;
        /**
         * The action to perform when the rule matches.
         */
        action?: 'force_connection_close';
        /**
         * The parameters configuring the rule's action.
         */
        action_parameters?: unknown;
        /**
         * The categories of the rule.
         */
        categories?: Array<string>;
        /**
         * An informative description of the rule.
         */
        description?: string;
        /**
         * Whether the rule should be executed.
         */
        enabled?: boolean;
        /**
         * The expression defining which traffic will match the rule.
         */
        expression?: string;
        /**
         * An object configuring the rule's logging behavior.
         */
        logging?: RulesAPI.Logging;
        /**
         * The reference of the rule (the rule ID by default).
         */
        ref?: string;
    }
}
export interface ByTagGetParams {
    /**
     * The unique ID of the account.
     */
    account_id: string;
}
export declare namespace ByTag {
    export import ByTagGetResponse = ByTagAPI.ByTagGetResponse;
    export import ByTagGetParams = ByTagAPI.ByTagGetParams;
}
//# sourceMappingURL=by-tag.d.ts.map