import * as Core from "../../core.js";
import { APIResource } from "../../resource.js";
import * as ACLsAPI from "./acls.js";
import { SinglePage } from "../../pagination.js";
export declare class ACLs extends APIResource {
    /**
     * Create ACL.
     */
    create(params: ACLCreateParams, options?: Core.RequestOptions): Core.APIPromise<ACL>;
    /**
     * Modify ACL.
     */
    update(aclId: string, params: ACLUpdateParams, options?: Core.RequestOptions): Core.APIPromise<ACL>;
    /**
     * List ACLs.
     */
    list(params: ACLListParams, options?: Core.RequestOptions): Core.PagePromise<ACLsSinglePage, ACL>;
    /**
     * Delete ACL.
     */
    delete(aclId: string, params: ACLDeleteParams, options?: Core.RequestOptions): Core.APIPromise<ACLDeleteResponse>;
    /**
     * Get ACL.
     */
    get(aclId: string, params: ACLGetParams, options?: Core.RequestOptions): Core.APIPromise<ACL>;
}
export declare class ACLsSinglePage extends SinglePage<ACL> {
}
export interface ACL {
    id: string;
    /**
     * Allowed IPv4/IPv6 address range of primary or secondary nameservers. This will
     * be applied for the entire account. The IP range is used to allow additional
     * NOTIFY IPs for secondary zones and IPs Cloudflare allows AXFR/IXFR requests from
     * for primary zones. CIDRs are limited to a maximum of /24 for IPv4 and /64 for
     * IPv6 respectively.
     */
    ip_range: string;
    /**
     * The name of the acl.
     */
    name: string;
}
export interface ACLDeleteResponse {
    id?: string;
}
export interface ACLCreateParams {
    /**
     * Path param:
     */
    account_id: string;
    /**
     * Body param:
     */
    body: unknown;
}
export interface ACLUpdateParams {
    /**
     * Path param:
     */
    account_id: string;
    /**
     * Body param: Allowed IPv4/IPv6 address range of primary or secondary nameservers.
     * This will be applied for the entire account. The IP range is used to allow
     * additional NOTIFY IPs for secondary zones and IPs Cloudflare allows AXFR/IXFR
     * requests from for primary zones. CIDRs are limited to a maximum of /24 for IPv4
     * and /64 for IPv6 respectively.
     */
    ip_range: string;
    /**
     * Body param: The name of the acl.
     */
    name: string;
}
export interface ACLListParams {
    account_id: string;
}
export interface ACLDeleteParams {
    account_id: string;
}
export interface ACLGetParams {
    account_id: string;
}
export declare namespace ACLs {
    export import ACL = ACLsAPI.ACL;
    export import ACLDeleteResponse = ACLsAPI.ACLDeleteResponse;
    export import ACLsSinglePage = ACLsAPI.ACLsSinglePage;
    export import ACLCreateParams = ACLsAPI.ACLCreateParams;
    export import ACLUpdateParams = ACLsAPI.ACLUpdateParams;
    export import ACLListParams = ACLsAPI.ACLListParams;
    export import ACLDeleteParams = ACLsAPI.ACLDeleteParams;
    export import ACLGetParams = ACLsAPI.ACLGetParams;
}
//# sourceMappingURL=acls.d.ts.map