import * as Core from "../../../../core.js";
import { APIResource } from "../../../../resource.js";
import * as LanguageAPI from "./language.js";
import * as CaptionsAPI from "../captions.js";
import * as VttAPI from "./vtt.js";
export declare class Language extends APIResource {
    vtt: VttAPI.Vtt;
    /**
     * Uploads the caption or subtitle file to the endpoint for a specific BCP47
     * language. One caption or subtitle file per language is allowed.
     */
    update(identifier: string, language: string, params: LanguageUpdateParams, options?: Core.RequestOptions): Core.APIPromise<CaptionsAPI.Caption>;
    /**
     * Removes the captions or subtitles from a video.
     */
    delete(identifier: string, language: string, params: LanguageDeleteParams, options?: Core.RequestOptions): Core.APIPromise<LanguageDeleteResponse>;
    /**
     * Lists the captions or subtitles for provided language.
     */
    get(identifier: string, language: string, params: LanguageGetParams, options?: Core.RequestOptions): Core.APIPromise<CaptionsAPI.Caption>;
}
export type LanguageDeleteResponse = string;
export interface LanguageUpdateParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param: The WebVTT file containing the caption or subtitle content.
     */
    file: string;
}
export interface LanguageDeleteParams {
    /**
     * Identifier
     */
    account_id: string;
}
export interface LanguageGetParams {
    /**
     * Identifier
     */
    account_id: string;
}
export declare namespace Language {
    export import LanguageDeleteResponse = LanguageAPI.LanguageDeleteResponse;
    export import LanguageUpdateParams = LanguageAPI.LanguageUpdateParams;
    export import LanguageDeleteParams = LanguageAPI.LanguageDeleteParams;
    export import LanguageGetParams = LanguageAPI.LanguageGetParams;
    export import Vtt = VttAPI.Vtt;
    export import VttGetResponse = VttAPI.VttGetResponse;
    export import VttGetParams = VttAPI.VttGetParams;
}
//# sourceMappingURL=language.d.ts.map