import * as Core from "../../../../../core.js";
import { APIResource } from "../../../../../resource.js";
import * as ContentListsAPI from "./content-lists.js";
import * as EntriesAPI from "./entries.js";
export declare class ContentLists extends APIResource {
    entries: EntriesAPI.Entries;
    /**
     * Update IPFS Universal Path Gateway Content List
     */
    update(zoneIdentifier: string, identifier: string, body: ContentListUpdateParams, options?: Core.RequestOptions): Core.APIPromise<ContentList>;
    /**
     * IPFS Universal Path Gateway Content List Details
     */
    get(zoneIdentifier: string, identifier: string, options?: Core.RequestOptions): Core.APIPromise<ContentList>;
}
export interface ContentList {
    /**
     * Behavior of the content list.
     */
    action?: 'block';
}
export interface ContentListUpdateParams {
    /**
     * Behavior of the content list.
     */
    action: 'block';
    /**
     * Content list entries.
     */
    entries: Array<ContentListUpdateParams.Entry>;
}
export declare namespace ContentListUpdateParams {
    /**
     * Content list entry to be blocked.
     */
    interface Entry {
        /**
         * CID or content path of content to block.
         */
        content?: string;
        /**
         * An optional description of the content list entry.
         */
        description?: string;
        /**
         * Type of content list entry to block.
         */
        type?: 'cid' | 'content_path';
    }
}
export declare namespace ContentLists {
    export import ContentList = ContentListsAPI.ContentList;
    export import ContentListUpdateParams = ContentListsAPI.ContentListUpdateParams;
    export import Entries = EntriesAPI.Entries;
    export import EntryCreateResponse = EntriesAPI.EntryCreateResponse;
    export import EntryUpdateResponse = EntriesAPI.EntryUpdateResponse;
    export import EntryListResponse = EntriesAPI.EntryListResponse;
    export import EntryDeleteResponse = EntriesAPI.EntryDeleteResponse;
    export import EntryGetResponse = EntriesAPI.EntryGetResponse;
    export import EntryCreateParams = EntriesAPI.EntryCreateParams;
    export import EntryUpdateParams = EntriesAPI.EntryUpdateParams;
}
//# sourceMappingURL=content-lists.d.ts.map