import * as Core from "../../../core.js";
import { APIResource } from "../../../resource.js";
import * as DeploymentsAPI from "./deployments.js";
export declare class Deployments extends APIResource {
    /**
     * Deployments configure how
     * [Worker Versions](https://developers.cloudflare.com/api/operations/worker-versions-list-versions)
     * are deployed to traffic. A deployment can consist of one or two versions of a
     * Worker.
     */
    create(scriptName: string, params: DeploymentCreateParams, options?: Core.RequestOptions): Core.APIPromise<DeploymentCreateResponse>;
    /**
     * List of Worker Deployments. The first deployment in the list is the latest
     * deployment actively serving traffic.
     */
    get(scriptName: string, params: DeploymentGetParams, options?: Core.RequestOptions): Core.APIPromise<DeploymentGetResponse>;
}
export interface Deployment {
    /**
     * Human-readable message about the deployment.
     */
    'workers/message'?: string;
}
export interface DeploymentParam {
    /**
     * Human-readable message about the deployment.
     */
    'workers/message'?: string;
}
export interface DeploymentCreateResponse {
    id?: string;
    annotations?: Deployment;
    author_email?: string;
    created_on?: string;
    source?: string;
    strategy?: string;
}
export interface DeploymentGetResponse {
    deployments?: Array<DeploymentGetResponse.Deployment>;
}
export declare namespace DeploymentGetResponse {
    interface Deployment {
        id?: string;
        annotations?: DeploymentsAPI.Deployment;
        author_email?: string;
        created_on?: string;
        source?: string;
        strategy?: string;
    }
}
export interface DeploymentCreateParams {
    /**
     * Path param: Identifier
     */
    account_id: string;
    /**
     * Body param:
     */
    annotations?: DeploymentParam;
    /**
     * Body param:
     */
    strategy?: string;
}
export interface DeploymentGetParams {
    /**
     * Identifier
     */
    account_id: string;
}
export declare namespace Deployments {
    export import Deployment = DeploymentsAPI.Deployment;
    export import DeploymentCreateResponse = DeploymentsAPI.DeploymentCreateResponse;
    export import DeploymentGetResponse = DeploymentsAPI.DeploymentGetResponse;
    export import DeploymentCreateParams = DeploymentsAPI.DeploymentCreateParams;
    export import DeploymentGetParams = DeploymentsAPI.DeploymentGetParams;
}
//# sourceMappingURL=deployments.d.ts.map