import * as Core from "../../../../core.js";
import { APIResource } from "../../../../resource.js";
import * as UsersAPI from "./users.js";
import * as ActiveSessionsAPI from "./active-sessions.js";
import * as FailedLoginsAPI from "./failed-logins.js";
import * as LastSeenIdentityAPI from "./last-seen-identity.js";
import { SinglePage } from "../../../../pagination.js";
export declare class Users extends APIResource {
    activeSessions: ActiveSessionsAPI.ActiveSessions;
    lastSeenIdentity: LastSeenIdentityAPI.LastSeenIdentity;
    failedLogins: FailedLoginsAPI.FailedLogins;
    /**
     * Gets a list of users for an account.
     */
    list(params: UserListParams, options?: Core.RequestOptions): Core.PagePromise<AccessUsersSinglePage, AccessUser>;
}
export declare class AccessUsersSinglePage extends SinglePage<AccessUser> {
}
export interface AccessUser {
    /**
     * UUID
     */
    id?: string;
    /**
     * True if the user has authenticated with Cloudflare Access.
     */
    access_seat?: boolean;
    /**
     * The number of active devices registered to the user.
     */
    active_device_count?: number;
    created_at?: string;
    /**
     * The email of the user.
     */
    email?: string;
    /**
     * True if the user has logged into the WARP client.
     */
    gateway_seat?: boolean;
    /**
     * The time at which the user last successfully logged in.
     */
    last_successful_login?: string;
    /**
     * The name of the user.
     */
    name?: string;
    /**
     * The unique API identifier for the Zero Trust seat.
     */
    seat_uid?: string;
    /**
     * The unique API identifier for the user.
     */
    uid?: string;
    updated_at?: string;
}
export interface UserListParams {
    /**
     * Identifier
     */
    account_id: string;
}
export declare namespace Users {
    export import AccessUser = UsersAPI.AccessUser;
    export import AccessUsersSinglePage = UsersAPI.AccessUsersSinglePage;
    export import UserListParams = UsersAPI.UserListParams;
    export import ActiveSessions = ActiveSessionsAPI.ActiveSessions;
    export import ActiveSessionListResponse = ActiveSessionsAPI.ActiveSessionListResponse;
    export import ActiveSessionGetResponse = ActiveSessionsAPI.ActiveSessionGetResponse;
    export import ActiveSessionListResponsesSinglePage = ActiveSessionsAPI.ActiveSessionListResponsesSinglePage;
    export import ActiveSessionListParams = ActiveSessionsAPI.ActiveSessionListParams;
    export import ActiveSessionGetParams = ActiveSessionsAPI.ActiveSessionGetParams;
    export import LastSeenIdentity = LastSeenIdentityAPI.LastSeenIdentity;
    export import Identity = LastSeenIdentityAPI.Identity;
    export import LastSeenIdentityGetParams = LastSeenIdentityAPI.LastSeenIdentityGetParams;
    export import FailedLogins = FailedLoginsAPI.FailedLogins;
    export import FailedLoginListResponse = FailedLoginsAPI.FailedLoginListResponse;
    export import FailedLoginListResponsesSinglePage = FailedLoginsAPI.FailedLoginListResponsesSinglePage;
    export import FailedLoginListParams = FailedLoginsAPI.FailedLoginListParams;
}
//# sourceMappingURL=users.d.ts.map