import * as Core from "../../core.js";
import { APIResource } from "../../resource.js";
import * as ConnectivitySettingsAPI from "./connectivity-settings.js";
export declare class ConnectivitySettings extends APIResource {
    /**
     * Updates the Zero Trust Connectivity Settings for the given account.
     */
    edit(params: ConnectivitySettingEditParams, options?: Core.RequestOptions): Core.APIPromise<ConnectivitySettingEditResponse>;
    /**
     * Gets the Zero Trust Connectivity Settings for the given account.
     */
    get(params: ConnectivitySettingGetParams, options?: Core.RequestOptions): Core.APIPromise<ConnectivitySettingGetResponse>;
}
export interface ConnectivitySettingEditResponse {
    /**
     * A flag to enable the ICMP proxy for the account network.
     */
    icmp_proxy_enabled?: boolean;
    /**
     * A flag to enable WARP to WARP traffic.
     */
    offramp_warp_enabled?: boolean;
}
export interface ConnectivitySettingGetResponse {
    /**
     * A flag to enable the ICMP proxy for the account network.
     */
    icmp_proxy_enabled?: boolean;
    /**
     * A flag to enable WARP to WARP traffic.
     */
    offramp_warp_enabled?: boolean;
}
export interface ConnectivitySettingEditParams {
    /**
     * Path param: Cloudflare account ID
     */
    account_id: string;
    /**
     * Body param: A flag to enable the ICMP proxy for the account network.
     */
    icmp_proxy_enabled?: boolean;
    /**
     * Body param: A flag to enable WARP to WARP traffic.
     */
    offramp_warp_enabled?: boolean;
}
export interface ConnectivitySettingGetParams {
    /**
     * Cloudflare account ID
     */
    account_id: string;
}
export declare namespace ConnectivitySettings {
    export import ConnectivitySettingEditResponse = ConnectivitySettingsAPI.ConnectivitySettingEditResponse;
    export import ConnectivitySettingGetResponse = ConnectivitySettingsAPI.ConnectivitySettingGetResponse;
    export import ConnectivitySettingEditParams = ConnectivitySettingsAPI.ConnectivitySettingEditParams;
    export import ConnectivitySettingGetParams = ConnectivitySettingsAPI.ConnectivitySettingGetParams;
}
//# sourceMappingURL=connectivity-settings.d.ts.map