import * as Core from "../../../core.js";
import { APIResource } from "../../../resource.js";
import * as ColosAPI from "./colos.js";
import { SinglePage } from "../../../pagination.js";
export declare class Colos extends APIResource {
    /**
     * List Cloudflare colos that account's devices were connected to during a time
     * period, sorted by usage starting from the most used colo. Colos without traffic
     * are also returned and sorted alphabetically.
     */
    list(params: ColoListParams, options?: Core.RequestOptions): Core.PagePromise<ColoListResponsesSinglePage, ColoListResponse>;
}
export declare class ColoListResponsesSinglePage extends SinglePage<ColoListResponse> {
}
export type ColoListResponse = unknown;
export interface ColoListParams {
    /**
     * Path param: unique identifier linked to an account in the API request path.
     */
    account_id: string;
    /**
     * Query param: Start time for connection period in RFC3339 (ISO 8601) format.
     */
    from: string;
    /**
     * Query param: End time for connection period in RFC3339 (ISO 8601) format.
     */
    to: string;
    /**
     * Query param: Type of usage that colos should be sorted by. If unspecified,
     * returns all Cloudflare colos sorted alphabetically.
     */
    sortBy?: 'fleet-status-usage' | 'application-tests-usage';
}
export declare namespace Colos {
    export import ColoListResponse = ColosAPI.ColoListResponse;
    export import ColoListResponsesSinglePage = ColosAPI.ColoListResponsesSinglePage;
    export import ColoListParams = ColosAPI.ColoListParams;
}
//# sourceMappingURL=colos.d.ts.map