import * as Core from "../../../core.js";
import { APIResource } from "../../../resource.js";
import * as ImageResizingAPI from "./image-resizing.js";
export declare class ImageResizingResource extends APIResource {
    /**
     * Image Resizing provides on-demand resizing, conversion and optimisation for
     * images served through Cloudflare's network. Refer to the
     * [Image Resizing documentation](https://developers.cloudflare.com/images/) for
     * more information.
     */
    edit(params: ImageResizingEditParams, options?: Core.RequestOptions): Core.APIPromise<ImageResizing>;
    /**
     * Image Resizing provides on-demand resizing, conversion and optimisation for
     * images served through Cloudflare's network. Refer to the
     * [Image Resizing documentation](https://developers.cloudflare.com/images/) for
     * more information.
     */
    get(params: ImageResizingGetParams, options?: Core.RequestOptions): Core.APIPromise<ImageResizing>;
}
/**
 * Image Resizing provides on-demand resizing, conversion and optimisation for
 * images served through Cloudflare's network. Refer to the
 * [Image Resizing documentation](https://developers.cloudflare.com/images/) for
 * more information.
 */
export interface ImageResizing {
    /**
     * ID of the zone setting.
     */
    id: 'image_resizing';
    /**
     * Current value of the zone setting.
     */
    value: 'on' | 'off' | 'open';
    /**
     * Whether or not this setting can be modified for this zone (based on your
     * Cloudflare plan level).
     */
    editable?: true | false;
    /**
     * last time this setting was modified.
     */
    modified_on?: string | null;
}
/**
 * Image Resizing provides on-demand resizing, conversion and optimisation for
 * images served through Cloudflare's network. Refer to the
 * [Image Resizing documentation](https://developers.cloudflare.com/images/) for
 * more information.
 */
export interface ImageResizingParam {
    /**
     * ID of the zone setting.
     */
    id: 'image_resizing';
    /**
     * Current value of the zone setting.
     */
    value: 'on' | 'off' | 'open';
}
export interface ImageResizingEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Image Resizing provides on-demand resizing, conversion and
     * optimisation for images served through Cloudflare's network. Refer to the
     * [Image Resizing documentation](https://developers.cloudflare.com/images/) for
     * more information.
     */
    value: ImageResizingParam;
}
export interface ImageResizingGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace ImageResizingResource {
    export import ImageResizing = ImageResizingAPI.ImageResizing;
    export import ImageResizingEditParams = ImageResizingAPI.ImageResizingEditParams;
    export import ImageResizingGetParams = ImageResizingAPI.ImageResizingGetParams;
}
//# sourceMappingURL=image-resizing.d.ts.map