import * as Core from "../../../core.js";
import { APIResource } from "../../../resource.js";
import * as TrueClientIPHeaderAPI from "./true-client-ip-header.js";
export declare class TrueClientIPHeaderResource extends APIResource {
    /**
     * Allows customer to continue to use True Client IP (Akamai feature) in the
     * headers we send to the origin. This is limited to Enterprise Zones.
     */
    edit(params: TrueClientIPHeaderEditParams, options?: Core.RequestOptions): Core.APIPromise<TrueClientIPHeader>;
    /**
     * Allows customer to continue to use True Client IP (Akamai feature) in the
     * headers we send to the origin. This is limited to Enterprise Zones.
     */
    get(params: TrueClientIPHeaderGetParams, options?: Core.RequestOptions): Core.APIPromise<TrueClientIPHeader>;
}
/**
 * Allows customer to continue to use True Client IP (Akamai feature) in the
 * headers we send to the origin. This is limited to Enterprise Zones.
 */
export interface TrueClientIPHeader {
    /**
     * ID of the zone setting.
     */
    id: 'true_client_ip_header';
    /**
     * Current value of the zone setting.
     */
    value: 'on' | 'off';
    /**
     * Whether or not this setting can be modified for this zone (based on your
     * Cloudflare plan level).
     */
    editable?: true | false;
    /**
     * last time this setting was modified.
     */
    modified_on?: string | null;
}
export interface TrueClientIPHeaderEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Value of the zone setting.
     */
    value: 'on' | 'off';
}
export interface TrueClientIPHeaderGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace TrueClientIPHeaderResource {
    export import TrueClientIPHeader = TrueClientIPHeaderAPI.TrueClientIPHeader;
    export import TrueClientIPHeaderEditParams = TrueClientIPHeaderAPI.TrueClientIPHeaderEditParams;
    export import TrueClientIPHeaderGetParams = TrueClientIPHeaderAPI.TrueClientIPHeaderGetParams;
}
//# sourceMappingURL=true-client-ip-header.d.ts.map